@@ -16,12 +16,12 @@ compiletest() {
   echo "Using LIBS:   $LIBS"
   echo
   echo "Compiling ${name}.c"
-  echoexec gcc -c -o $ADTTMP/${name}.o debian/tests/src/${name}.c $CFLAGS
+  echoexec gcc -c -o $AUTOPKGTEST_TMP/${name}.o debian/tests/src/${name}.c $CFLAGS
   echo
   echo "Linking ${name}"
-  echoexec gcc -o $ADTTMP/$name $ADTTMP/${name}.o $LIBS
+  echoexec gcc -o $AUTOPKGTEST_TMP/$name $AUTOPKGTEST_TMP/${name}.o $LIBS
   echo
   echo "Execute built binary: ${name}"
-  chmod a+x $ADTTMP/$name
-  echoexec $ADTTMP/$name
+  chmod a+x $AUTOPKGTEST_TMP/$name
+  echoexec $AUTOPKGTEST_TMP/$name
 }
